← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/bug-1542705 into lp:widelands

 

GunChleoc has proposed merging lp:~widelands-dev/widelands/bug-1542705 into lp:widelands.

Commit message:
Renamed program "geologist-find" to "geologist_find" and "playFX" to "play_sound".

Requested reviews:
  Widelands Developers (widelands-dev)
Related bugs:
  Bug #1542705 in widelands: "Consolidate names in bob workes programs"
  https://bugs.launchpad.net/widelands/+bug/1542705

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/bug-1542705/+merge/286187

Renamed program "geologist-find" to "geologist_find" and "playFX" to "play_sound".

-- 
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/bug-1542705 into lp:widelands.
=== modified file 'data/tribes/buildings/productionsites/atlanteans/horsefarm/init.lua'
--- data/tribes/buildings/productionsites/atlanteans/horsefarm/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/atlanteans/horsefarm/init.lua	2016-02-16 15:29:05 +0000
@@ -54,7 +54,7 @@
             "sleep=15000",
             "return=skipped unless economy needs atlanteans_horse",
             "consume=corn water",
-            "playFX=sound/farm horse 192",
+            "play_sound=sound/farm horse 192",
             "animate=working 15000", -- Feeding cute little foals ;)
             "recruit=atlanteans_horse"
          }

=== modified file 'data/tribes/buildings/productionsites/atlanteans/sawmill/init.lua'
--- data/tribes/buildings/productionsites/atlanteans/sawmill/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/atlanteans/sawmill/init.lua	2016-02-16 15:29:05 +0000
@@ -56,7 +56,7 @@
             "sleep=16500", -- Much faster than barbarians' wood hardener
             "return=skipped unless economy needs planks",
             "consume=log:2",
-            "playFX=sound/sawmill sawmill 192",
+            "play_sound=sound/sawmill sawmill 192",
             "animate=working 20000", -- Much faster than barbarians' wood hardener
             "produce=planks"
          }

=== modified file 'data/tribes/buildings/productionsites/atlanteans/weaponsmithy/init.lua'
--- data/tribes/buildings/productionsites/atlanteans/weaponsmithy/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/atlanteans/weaponsmithy/init.lua	2016-02-16 15:29:05 +0000
@@ -75,9 +75,9 @@
             "return=skipped unless economy needs trident_light",
             "sleep=20000",
             "consume=iron planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 30000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=trident_light"
          }
       },
@@ -88,9 +88,9 @@
             "return=skipped unless economy needs trident_long",
             "sleep=32000",
             "consume=iron coal planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=trident_long"
          }
       },
@@ -101,9 +101,9 @@
             "return=skipped unless economy needs trident_steel",
             "sleep=32000",
             "consume=iron:2 coal planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=trident_steel"
          }
       },
@@ -114,9 +114,9 @@
             "return=skipped unless economy needs trident_double",
             "sleep=32000",
             "consume=iron coal:2 planks gold",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=trident_double"
          }
       },
@@ -127,9 +127,9 @@
             "return=skipped unless economy needs trident_heavy_double",
             "sleep=32000",
             "consume=iron:2 coal:2 planks gold",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=trident_heavy_double"
          }
       },

=== modified file 'data/tribes/buildings/productionsites/barbarians/ax_workshop/init.lua'
--- data/tribes/buildings/productionsites/barbarians/ax_workshop/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/barbarians/ax_workshop/init.lua	2016-02-16 15:29:05 +0000
@@ -77,9 +77,9 @@
             "return=skipped unless economy needs ax",
             "sleep=32000",
             "consume=coal iron",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax"
          }
       },
@@ -90,9 +90,9 @@
             "return=skipped unless economy needs ax_sharp",
             "sleep=32000",
             "consume=coal iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_sharp"
          }
       },
@@ -103,9 +103,9 @@
             "return=skipped unless economy needs ax_broad",
             "sleep=32000",
             "consume=coal:2 iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_broad"
          }
       },

=== modified file 'data/tribes/buildings/productionsites/barbarians/cattlefarm/init.lua'
--- data/tribes/buildings/productionsites/barbarians/cattlefarm/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/barbarians/cattlefarm/init.lua	2016-02-16 15:29:05 +0000
@@ -54,7 +54,7 @@
             "sleep=15000",
             "return=skipped unless economy needs barbarians_ox",
             "consume=wheat water",
-            "playFX=sound/farm ox 192",
+            "play_sound=sound/farm ox 192",
             "animate=working 15000", -- Animation of feeding the cattle
             "recruit=barbarians_ox"
          }

=== modified file 'data/tribes/buildings/productionsites/barbarians/metal_workshop/init.lua'
--- data/tribes/buildings/productionsites/barbarians/metal_workshop/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/barbarians/metal_workshop/init.lua	2016-02-16 15:29:05 +0000
@@ -94,7 +94,7 @@
             "return=skipped unless economy needs bread_paddle",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=bread_paddle"
          }
@@ -106,7 +106,7 @@
             "return=skipped unless economy needs felling_ax",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=felling_ax"
          }
@@ -118,7 +118,7 @@
             "return=skipped unless economy needs fire_tongs",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=fire_tongs"
          }
@@ -130,7 +130,7 @@
             "return=skipped unless economy needs fishing_rod",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=fishing_rod"
          }
@@ -142,7 +142,7 @@
             "return=skipped unless economy needs hammer",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=hammer"
          }
@@ -154,7 +154,7 @@
             "return=skipped unless economy needs hunting_spear",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=hunting_spear"
          }
@@ -166,7 +166,7 @@
             "return=skipped unless economy needs kitchen_tools",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=kitchen_tools"
          }
@@ -178,7 +178,7 @@
             "return=skipped unless economy needs pick",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=pick"
          }
@@ -190,7 +190,7 @@
             "return=skipped unless economy needs scythe",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=scythe"
          }
@@ -202,7 +202,7 @@
             "return=skipped unless economy needs shovel",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=shovel"
          }

=== modified file 'data/tribes/buildings/productionsites/barbarians/warmill/init.lua'
--- data/tribes/buildings/productionsites/barbarians/warmill/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/barbarians/warmill/init.lua	2016-02-16 15:29:05 +0000
@@ -84,9 +84,9 @@
             "return=skipped unless economy needs ax",
             "sleep=32000",
             "consume=coal iron",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax"
          }
       },
@@ -97,9 +97,9 @@
             "return=skipped unless economy needs ax_sharp",
             "sleep=32000",
             "consume=coal iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_sharp"
          }
       },
@@ -110,9 +110,9 @@
             "return=skipped unless economy needs ax_broad",
             "sleep=32000",
             "consume=coal:2 iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_broad"
          }
       },
@@ -123,9 +123,9 @@
             "return=skipped unless economy needs ax_bronze",
             "sleep=32000",
             "consume=coal:2 iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_bronze"
          }
       },
@@ -136,9 +136,9 @@
             "return=skipped unless economy needs ax_battle",
             "sleep=32000",
             "consume=coal gold iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_battle"
          }
       },
@@ -149,9 +149,9 @@
             "return=skipped unless economy needs ax_warriors",
             "sleep=32000",
             "consume=coal:2 gold:2 iron:2",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 25000",
-            "playFX=sound/smiths sharpening 192",
+            "play_sound=sound/smiths sharpening 192",
             "produce=ax_warriors"
          }
       },

=== modified file 'data/tribes/buildings/productionsites/empire/donkeyfarm/init.lua'
--- data/tribes/buildings/productionsites/empire/donkeyfarm/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/donkeyfarm/init.lua	2016-02-16 15:29:05 +0000
@@ -54,7 +54,7 @@
             "sleep=15000",
             "return=skipped unless economy needs empire_donkey",
             "consume=wheat water",
-            "playFX=sound/farm donkey 192",
+            "play_sound=sound/farm donkey 192",
             "animate=working 15000", -- Feeding cute little baby donkeys ;)
             "recruit=empire_donkey"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/mill/init.lua'
--- data/tribes/buildings/productionsites/empire/mill/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/mill/init.lua	2016-02-16 15:29:05 +0000
@@ -55,7 +55,7 @@
             "sleep=5000",
             "return=skipped unless economy needs flour",
             "consume=wheat",
-            "playFX=sound/mill mill_turning 240",
+            "play_sound=sound/mill mill_turning 240",
             "animate=working 10000",
             "produce=flour"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/piggery/init.lua'
--- data/tribes/buildings/productionsites/empire/piggery/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/piggery/init.lua	2016-02-16 15:29:05 +0000
@@ -56,7 +56,7 @@
             "sleep=25000",
             "return=skipped unless economy needs meat",
             "consume=water wheat",
-            "playFX=sound/farm farm_animal 180",
+            "play_sound=sound/farm farm_animal 180",
             "animate=working 30000",
             "produce=meat"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/sawmill/init.lua'
--- data/tribes/buildings/productionsites/empire/sawmill/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/sawmill/init.lua	2016-02-16 15:29:05 +0000
@@ -56,7 +56,7 @@
             "sleep=16500", -- Much faster than barbarians' wood hardener
             "return=skipped unless economy needs planks",
             "consume=log:2",
-            "playFX=sound/sawmill sawmill 180",
+            "play_sound=sound/sawmill sawmill 180",
             "animate=working 20000", -- Much faster than barbarians' wood hardener
             "produce=planks"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/sheepfarm/init.lua'
--- data/tribes/buildings/productionsites/empire/sheepfarm/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/sheepfarm/init.lua	2016-02-16 15:29:05 +0000
@@ -54,7 +54,7 @@
             "sleep=25000",
             "return=skipped unless economy needs wool",
             "consume=water wheat",
-            "playFX=sound/farm sheep 192",
+            "play_sound=sound/farm sheep 192",
             "animate=working 30000",
             "produce=wool"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/stonemasons_house/init.lua'
--- data/tribes/buildings/productionsites/empire/stonemasons_house/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/stonemasons_house/init.lua	2016-02-16 15:29:05 +0000
@@ -57,7 +57,7 @@
             "sleep=50000",
             "return=skipped unless economy needs marble_column",
             "consume=marble:2",
-            "playFX=sound/stonecutting stonemason 192",
+            "play_sound=sound/stonecutting stonemason 192",
             "animate=working 32000",
             "produce=marble_column"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/toolsmithy/init.lua'
--- data/tribes/buildings/productionsites/empire/toolsmithy/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/toolsmithy/init.lua	2016-02-16 15:29:05 +0000
@@ -86,7 +86,7 @@
             "return=skipped unless economy needs felling_ax",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=felling_ax"
          }
@@ -98,7 +98,7 @@
             "return=skipped unless economy needs basket",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=basket"
          }
@@ -110,7 +110,7 @@
             "return=skipped unless economy needs bread_paddle",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=bread_paddle"
          }
@@ -122,7 +122,7 @@
             "return=skipped unless economy needs fire_tongs",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=fire_tongs"
          }
@@ -134,7 +134,7 @@
             "return=skipped unless economy needs fishing_rod",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=fishing_rod"
          }
@@ -146,7 +146,7 @@
             "return=skipped unless economy needs hammer",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=hammer"
          }
@@ -158,7 +158,7 @@
             "return=skipped unless economy needs hunting_spear",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=hunting_spear"
          }
@@ -170,7 +170,7 @@
             "return=skipped unless economy needs kitchen_tools",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=kitchen_tools"
          }
@@ -182,7 +182,7 @@
             "return=skipped unless economy needs pick",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=pick"
          }
@@ -194,7 +194,7 @@
             "return=skipped unless economy needs saw",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=saw"
          }
@@ -206,7 +206,7 @@
             "return=skipped unless economy needs scythe",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=scythe"
          }
@@ -218,7 +218,7 @@
             "return=skipped unless economy needs shovel",
             "sleep=32000",
             "consume=iron log",
-            "playFX=sound/smiths toolsmith 192",
+            "play_sound=sound/smiths toolsmith 192",
             "animate=working 35000",
             "produce=shovel"
          }

=== modified file 'data/tribes/buildings/productionsites/empire/weaponsmithy/init.lua'
--- data/tribes/buildings/productionsites/empire/weaponsmithy/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/buildings/productionsites/empire/weaponsmithy/init.lua	2016-02-16 15:29:05 +0000
@@ -80,9 +80,9 @@
             "return=skipped unless economy needs spear_wooden",
             "sleep=20000",
             "consume=planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 30000",
-            "playFX=sound/smiths sharpening 120",
+            "play_sound=sound/smiths sharpening 120",
             "produce=spear_wooden"
          }
       },
@@ -93,9 +93,9 @@
             "return=skipped unless economy needs spear",
             "sleep=32000",
             "consume=coal iron planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 120",
+            "play_sound=sound/smiths sharpening 120",
             "produce=spear"
          }
       },
@@ -106,9 +106,9 @@
             "return=skipped unless economy needs spear_advanced",
             "sleep=32000",
             "consume=coal iron:2 planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 120",
+            "play_sound=sound/smiths sharpening 120",
             "produce=spear_advanced"
          }
       },
@@ -119,9 +119,9 @@
             "return=skipped unless economy needs spear_heavy",
             "sleep=32000",
             "consume=coal:2 gold iron planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 120",
+            "play_sound=sound/smiths sharpening 120",
             "produce=spear_heavy"
          }
       },
@@ -132,9 +132,9 @@
             "return=skipped unless economy needs spear_war",
             "sleep=32000",
             "consume=coal:2 gold iron:2 planks",
-            "playFX=sound/smiths smith 192",
+            "play_sound=sound/smiths smith 192",
             "animate=working 45000",
-            "playFX=sound/smiths sharpening 120",
+            "play_sound=sound/smiths sharpening 120",
             "produce=spear_war"
          }
       },

=== modified file 'data/tribes/workers/atlanteans/farmer/init.lua'
--- data/tribes/workers/atlanteans/farmer/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/farmer/init.lua	2016-02-16 15:29:05 +0000
@@ -51,7 +51,7 @@
       harvest = {
          "findobject attrib:ripe_corn radius:2",
          "walk object",
-         "playFX sound/farm scythe 220",
+         "play_sound sound/farm scythe 220",
          "animation harvesting 10000",
          "object harvest",
          "animation gathering 4000",

=== modified file 'data/tribes/workers/atlanteans/fisher/init.lua'
--- data/tribes/workers/atlanteans/fisher/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/fisher/init.lua	2016-02-16 15:29:05 +0000
@@ -33,10 +33,10 @@
       fish = {
          "findspace size:any radius:7 resource:fish",
          "walk coords",
-         "playFX sound/fisher fisher_throw_net 192",
+         "play_sound sound/fisher fisher_throw_net 192",
          "mine fish 1",
          "animation fishing 3000",
-         "playFX sound/fisher fisher_pull_net 192",
+         "play_sound sound/fisher fisher_pull_net 192",
          "createware fish",
          "return"
       }

=== modified file 'data/tribes/workers/atlanteans/geologist/init.lua'
--- data/tribes/workers/atlanteans/geologist/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/geologist/init.lua	2016-02-16 15:29:05 +0000
@@ -41,9 +41,9 @@
       search = {
          "animation hacking 5000",
          "animation idle 2000",
-         "playFX sound/hammering geologist_hammer 192",
+         "play_sound sound/hammering geologist_hammer 192",
          "animation hacking 3000",
-         "geologist-find"
+         "geologist_find"
       }
    },
 

=== modified file 'data/tribes/workers/atlanteans/shipwright/init.lua'
--- data/tribes/workers/atlanteans/shipwright/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/shipwright/init.lua	2016-02-16 15:29:05 +0000
@@ -33,7 +33,7 @@
       buildship = {
          "walk object-or-coords",
          "plant tribe:atlanteans_shipconstruction unless object",
-         "playFX sound/sawmill sawmill 230",
+         "play_sound sound/sawmill sawmill 230",
          "animation idle 500",
          "construct",
          "animation idle 5000",

=== modified file 'data/tribes/workers/atlanteans/stonecutter/init.lua'
--- data/tribes/workers/atlanteans/stonecutter/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/stonecutter/init.lua	2016-02-16 15:29:05 +0000
@@ -33,7 +33,7 @@
       cut_granite = {
          "findobject attrib:rocks radius:6",
          "walk object",
-         "playFX sound/stonecutting stonecutter 192",
+         "play_sound sound/stonecutting stonecutter 192",
          "animation hacking 10000",
          "object shrink",
          "createware granite",

=== modified file 'data/tribes/workers/atlanteans/woodcutter/init.lua'
--- data/tribes/workers/atlanteans/woodcutter/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/atlanteans/woodcutter/init.lua	2016-02-16 15:29:05 +0000
@@ -33,7 +33,7 @@
       harvest = {
          "findobject attrib:tree radius:10",
          "walk object",
-         "playFX sound/sawmill sawmill 230",
+         "play_sound sound/sawmill sawmill 230",
          "animation sawing 10000",
          "object fall",
          "animation idle 2000",

=== modified file 'data/tribes/workers/barbarians/farmer/init.lua'
--- data/tribes/workers/barbarians/farmer/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/farmer/init.lua	2016-02-16 15:29:05 +0000
@@ -51,7 +51,7 @@
       harvest = {
          "findobject attrib:ripe_wheat radius:2",
          "walk object",
-         "playFX sound/farm scythe 220",
+         "play_sound sound/farm scythe 220",
          "animation harvesting 10000",
          "object harvest",
          "animation gathering 4000",

=== modified file 'data/tribes/workers/barbarians/fisher/init.lua'
--- data/tribes/workers/barbarians/fisher/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/fisher/init.lua	2016-02-16 15:29:05 +0000
@@ -33,10 +33,10 @@
       fish = {
          "findspace size:any radius:7 resource:fish",
          "walk coords",
-         "playFX sound/fisher fisher_throw_net 192",
+         "play_sound sound/fisher fisher_throw_net 192",
          "mine fish 1",
          "animation fishing 3000",
-         "playFX sound/fisher fisher_pull_net 192",
+         "play_sound sound/fisher fisher_pull_net 192",
          "createware fish",
          "return"
       }

=== modified file 'data/tribes/workers/barbarians/geologist/init.lua'
--- data/tribes/workers/barbarians/geologist/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/geologist/init.lua	2016-02-16 15:29:05 +0000
@@ -41,9 +41,9 @@
       search = {
          "animation hacking 5000",
          "animation idle 2000",
-         "playFX sound/hammering geologist_hammer 192",
+         "play_sound sound/hammering geologist_hammer 192",
          "animation hacking 3000",
-         "geologist-find"
+         "geologist_find"
       }
    },
 

=== modified file 'data/tribes/workers/barbarians/lumberjack/init.lua'
--- data/tribes/workers/barbarians/lumberjack/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/lumberjack/init.lua	2016-02-16 15:29:05 +0000
@@ -34,9 +34,9 @@
       chop = {
          "findobject attrib:tree radius:10",
          "walk object",
-         "playFX sound/woodcutting woodcutting 255",
+         "play_sound sound/woodcutting woodcutting 255",
          "animation hacking 10000",
-         "playFX sound/spoken timber 192",
+         "play_sound sound/spoken timber 192",
          "object fall",
          "animation idle 2000",
          "createware log",

=== modified file 'data/tribes/workers/barbarians/shipwright/init.lua'
--- data/tribes/workers/barbarians/shipwright/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/shipwright/init.lua	2016-02-16 15:29:05 +0000
@@ -37,7 +37,7 @@
       buildship = {
          "walk object-or-coords",
          "plant tribe:barbarians_shipconstruction unless object",
-         "playFX sound/sawmill sawmill 230",
+         "play_sound sound/sawmill sawmill 230",
          "animation work 500",
          "construct",
          "animation work 5000",

=== modified file 'data/tribes/workers/barbarians/stonemason/init.lua'
--- data/tribes/workers/barbarians/stonemason/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/barbarians/stonemason/init.lua	2016-02-16 15:29:05 +0000
@@ -34,7 +34,7 @@
       cut_granite = {
          "findobject attrib:rocks radius:6",
          "walk object",
-         "playFX sound/stonecutting stonecutter 192",
+         "play_sound sound/stonecutting stonecutter 192",
          "animation hacking 10000",
          "object shrink",
          "createware granite",

=== modified file 'data/tribes/workers/empire/farmer/init.lua'
--- data/tribes/workers/empire/farmer/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/farmer/init.lua	2016-02-16 15:29:05 +0000
@@ -51,7 +51,7 @@
       harvest = {
          "findobject attrib:ripe_wheat radius:2",
          "walk object",
-         "playFX sound/farm scythe 220",
+         "play_sound sound/farm scythe 220",
          "animation harvesting 10000",
          "object harvest",
          "animation gathering 4000",

=== modified file 'data/tribes/workers/empire/fisher/init.lua'
--- data/tribes/workers/empire/fisher/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/fisher/init.lua	2016-02-16 15:29:05 +0000
@@ -33,10 +33,10 @@
       fish = {
          "findspace size:any radius:7 resource:fish",
          "walk coords",
-         "playFX sound/fisher fisher_throw_net 192",
+         "play_sound sound/fisher fisher_throw_net 192",
          "mine fish 1",
          "animation fishing 3000", -- Play a fishing animation
-         "playFX sound/fisher fisher_pull_net 192",
+         "play_sound sound/fisher fisher_pull_net 192",
          "createware fish",
          "return"
       }

=== modified file 'data/tribes/workers/empire/geologist/init.lua'
--- data/tribes/workers/empire/geologist/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/geologist/init.lua	2016-02-16 15:29:05 +0000
@@ -41,9 +41,9 @@
       search = {
          "animation hacking 5000",
          "animation idle 2000",
-         "playFX sound/hammering geologist_hammer 192",
+         "play_sound sound/hammering geologist_hammer 192",
          "animation hacking 3000",
-         "geologist-find"
+         "geologist_find"
       }
    },
 

=== modified file 'data/tribes/workers/empire/lumberjack/init.lua'
--- data/tribes/workers/empire/lumberjack/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/lumberjack/init.lua	2016-02-16 15:29:05 +0000
@@ -34,9 +34,9 @@
       chop = {
          "findobject attrib:tree radius:10",
          "walk object",
-         "playFX sound/woodcutting fast_woodcutting 250",
+         "play_sound sound/woodcutting fast_woodcutting 250",
          "animation hacking 10000",
-         "playFX sound/spoken timber 156",
+         "play_sound sound/spoken timber 156",
          "object fall",
          "animation idle 2000",
          "createware log",

=== modified file 'data/tribes/workers/empire/shipwright/init.lua'
--- data/tribes/workers/empire/shipwright/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/shipwright/init.lua	2016-02-16 15:29:05 +0000
@@ -37,7 +37,7 @@
       buildship = {
          "walk object-or-coords",
          "plant tribe:empire_shipconstruction unless object",
-         "playFX sound/sawmill sawmill 230",
+         "play_sound sound/sawmill sawmill 230",
          "animation work 500",
          "construct",
          "animation work 5000",

=== modified file 'data/tribes/workers/empire/stonemason/init.lua'
--- data/tribes/workers/empire/stonemason/init.lua	2016-01-28 05:24:34 +0000
+++ data/tribes/workers/empire/stonemason/init.lua	2016-02-16 15:29:05 +0000
@@ -34,7 +34,7 @@
       cut_granite = {
          "findobject attrib:rocks radius:6",
          "walk object",
-         "playFX sound/stonecutting stonecutter 220",
+         "play_sound sound/stonecutting stonecutter 220",
          "animation hacking 10000",
          "object shrink",
          "createware granite",
@@ -43,7 +43,7 @@
       cut_marble = {
          "findobject attrib:rocks radius:6",
          "walk object",
-         "playFX sound/stonecutting stonecutter 220",
+         "play_sound sound/stonecutting stonecutter 220",
          "animation hacking 10000",
          "object shrink",
          "createware marble",

=== modified file 'doc/sphinx/source/productionsite_program.rst'
--- doc/sphinx/source/productionsite_program.rst	2012-06-15 20:29:49 +0000
+++ doc/sphinx/source/productionsite_program.rst	2016-02-16 15:29:05 +0000
@@ -14,7 +14,7 @@
 - `mine`_
 - `check_soldier`_
 - `train`_
-- `playFX`_
+- `play_sound`_
 
 
 return
@@ -196,7 +196,7 @@
 -----
 Increases the level of a specified property of a soldier. No further documentation available.
 
-playFX
+play_sound
 ------
 Plays a soundFX.
 

=== modified file 'src/graphic/animation.cc'
--- src/graphic/animation.h	2015-11-20 18:16:22 +0000
+++ src/graphic/animation.h	2016-02-16 15:29:05 +0000
@@ -84,7 +84,7 @@
 	virtual void blit(uint32_t time, const Point&, const Rect& srcrc, const RGBColor* clr, Surface*) const = 0;
 
 	/// Play the sound effect associated with this animation at the given time.
-	virtual void trigger_soundfx(uint32_t time, uint32_t stereo_position) const = 0;
+	virtual void trigger_sound(uint32_t time, uint32_t stereo_position) const = 0;
 
 private:
 	DISALLOW_COPY_AND_ASSIGN(Animation);

=== modified file 'src/graphic/rendertarget.cc'
--- src/logic/map_objects/immovable.cc	2016-02-10 19:50:13 +0000
+++ src/logic/map_objects/immovable.cc	2016-02-16 15:29:05 +0000
@@ -168,8 +168,8 @@
 			action = new ActRemove(arguments.get(), *immovable);
 		} else if (parts[0] == "seed") {
 			action = new ActSeed(arguments.get(), *immovable);
-		} else if (parts[0] == "playFX") {
-			action = new ActPlayFX(arguments.get(), *immovable);
+		} else if (parts[0] == "play_sound") {
+			action = new ActPlaySound(arguments.get(), *immovable);
 		} else if (parts[0] == "construction") {
 			action = new ActConstruction(arguments.get(), *immovable);
 		} else {
@@ -792,7 +792,7 @@
 }
 
 
-ImmovableProgram::ActPlayFX::ActPlayFX(char* parameters, const ImmovableDescr&) {
+ImmovableProgram::ActPlaySound::ActPlaySound(char* parameters, const ImmovableDescr&) {
 	try {
 		bool reached_end;
 		name = next_word(parameters, reached_end);
@@ -811,14 +811,14 @@
 													 FileSystem::fs_filename(name.c_str()),
 													 name);
 	} catch (const WException & e) {
-		throw GameDataError("playFX: %s", e.what());
+		throw GameDataError("play_sound: %s", e.what());
 	}
 }
 
 /** Demand from the g_sound_handler to play a certain sound effect.
  * Whether the effect actually gets played
  * is decided only by the sound server*/
-void ImmovableProgram::ActPlayFX::execute
+void ImmovableProgram::ActPlaySound::execute
 	(Game & game, Immovable & immovable) const
 {
 	g_sound_handler.play_fx(name, immovable.get_position(), priority);

=== modified file 'src/logic/map_objects/immovable_program.h'
--- src/logic/map_objects/immovable_program.h	2016-02-09 16:29:48 +0000
+++ src/logic/map_objects/immovable_program.h	2016-02-16 15:29:05 +0000
@@ -123,23 +123,22 @@
 		uint8_t probability;
 	};
 
-	/// Plays a soundFX.
+	/// Plays a sound effect.
 	///
 	/// Parameter syntax:
-	///    parameters ::= soundFX [priority]
+	///    parameters ::= directory sound [priority]
 	/// Parameter semantics:
 	///    directory:
-	///       The directory of the productionsite.
-	///    soundFX:
-	///       The filename of an soundFX (relative to the productionsite's
-	///       directory).
+	///       The directory of the sound files, relative to the datadir.
+	///    sound:
+	///       The base filename of a sound effect (relative to the directory).
 	///    priority:
 	///       An integer. If omitted, 127 is used.
 	///
-	/// Plays the specified soundFX with the specified priority. Whether the
-	/// soundFX is actually played is determined by the sound handler.
-	struct ActPlayFX : public Action {
-		ActPlayFX(char* parameters, const ImmovableDescr &);
+	/// Plays the specified sound effect with the specified priority. Whether the
+	/// sound effect is actually played is determined by the sound handler.
+	struct ActPlaySound : public Action {
+		ActPlaySound(char* parameters, const ImmovableDescr &);
 		void execute(Game &, Immovable &) const override;
 	private:
 		std::string name;

=== modified file 'src/logic/map_objects/tribes/production_program.cc'
--- src/logic/map_objects/tribes/production_program.cc	2016-02-15 22:31:59 +0000
+++ src/logic/map_objects/tribes/production_program.cc	2016-02-16 15:29:05 +0000
@@ -1519,7 +1519,7 @@
 	return ps.program_step(game);
 }
 
-ProductionProgram::ActPlayFX::ActPlayFX(char * parameters) {
+ProductionProgram::ActPlaySound::ActPlaySound(char * parameters) {
 	try {
 		bool reached_end;
 		const std::string& filepath = next_word(parameters, reached_end);
@@ -1538,11 +1538,11 @@
 
 		g_sound_handler.load_fx_if_needed(filepath, filename, name);
 	} catch (const WException & e) {
-		throw GameDataError("playFX: %s", e.what());
+		throw GameDataError("play_sound: %s", e.what());
 	}
 }
 
-void ProductionProgram::ActPlayFX::execute
+void ProductionProgram::ActPlaySound::execute
 	(Game & game, ProductionSite & ps) const
 {
 	g_sound_handler.play_fx(name, ps.position_, priority);
@@ -1772,9 +1772,9 @@
 		} else if (boost::iequals(parts[0], "train")) {
 			actions_.push_back(std::unique_ptr<ProductionProgram::Action>(
 										 new ActTrain(arguments.get())));
-		} else if (boost::iequals(parts[0], "playFX")) {
+		} else if (boost::iequals(parts[0], "play_sound")) {
 			actions_.push_back(std::unique_ptr<ProductionProgram::Action>(
-										 new ActPlayFX(arguments.get())));
+										 new ActPlaySound(arguments.get())));
 		} else if (boost::iequals(parts[0], "construct")) {
 			actions_.push_back(std::unique_ptr<ProductionProgram::Action>(
 										 new ActConstruct(arguments.get(), name(), building)));

=== modified file 'src/logic/map_objects/tribes/production_program.h'
--- src/logic/map_objects/tribes/production_program.h	2016-02-14 14:09:29 +0000
+++ src/logic/map_objects/tribes/production_program.h	2016-02-16 15:29:05 +0000
@@ -460,22 +460,22 @@
 		uint8_t target_level;
 	};
 
-	/// Plays a soundFX.
+	/// Plays a sound effect.
 	///
 	/// Parameter syntax:
-	///    parameters ::= soundFX [priority]
+	///    parameters ::= directory sound [priority]
 	/// Parameter semantics:
 	///    directory:
-	///       The directory of the sound effect.
-	///    soundFX:
-	///       The base filename of a soundFX (without path, running numbers or file extension)
+	///       The directory of the sound files, relative to the datadir.
+	///    sound:
+	///       The base filename of a sound effect (relative to the directory).
 	///    priority:
 	///       An integer. If omitted, 127 is used.
 	///
-	/// Plays the specified soundFX with the specified priority. Whether the
-	/// soundFX is actually played is determined by the sound handler.
-	struct ActPlayFX : public Action {
-		ActPlayFX(char * parameters);
+	/// Plays the specified sound effect with the specified priority. Whether the
+	/// sound effect is actually played is determined by the sound handler.
+	struct ActPlaySound : public Action {
+		ActPlaySound(char * parameters);
 		void execute(Game &, ProductionSite &) const override;
 	private:
 		std::string name;

=== modified file 'src/logic/map_objects/tribes/productionsite.h'
--- src/logic/map_objects/tribes/productionsite.h	2016-02-08 20:52:24 +0000
+++ src/logic/map_objects/tribes/productionsite.h	2016-02-16 15:29:05 +0000
@@ -133,7 +133,7 @@
 	friend struct ProductionProgram::ActMine;
 	friend struct ProductionProgram::ActCheckSoldier;
 	friend struct ProductionProgram::ActTrain;
-	friend struct ProductionProgram::ActPlayFX;
+	friend struct ProductionProgram::ActPlaySound;
 	friend struct ProductionProgram::ActConstruct;
 	MO_DESCR(ProductionSiteDescr)
 

=== modified file 'src/logic/map_objects/tribes/worker.cc'
--- src/logic/map_objects/tribes/worker.cc	2016-02-15 19:03:41 +0000
+++ src/logic/map_objects/tribes/worker.cc	2016-02-16 15:29:05 +0000
@@ -967,7 +967,7 @@
  * Demand from the g_sound_handler to play a certain sound effect.
  * Whether the effect actually gets played is decided only by the sound server.
  */
-bool Worker::run_playfx(Game & game, State & state, const Action & action)
+bool Worker::run_play_sound(Game & game, State & state, const Action & action)
 {
 	g_sound_handler.play_fx(action.sparam1, get_position(), action.iparam1);
 
@@ -2922,7 +2922,7 @@
 ==============================
 */
 
-constexpr uint8_t kCurrentPacketVersion = 2;
+constexpr uint8_t kCurrentPacketVersion = 3;
 
 Worker::Loader::Loader() :
 	location_(0),

=== modified file 'src/logic/map_objects/tribes/worker.h'
--- src/logic/map_objects/tribes/worker.h	2016-02-09 07:42:38 +0000
+++ src/logic/map_objects/tribes/worker.h	2016-02-16 15:29:05 +0000
@@ -239,7 +239,7 @@
 	bool run_geologist        (Game &, State &, const Action &);
 	bool run_geologist_find   (Game &, State &, const Action &);
 	bool run_scout            (Game &, State &, const Action &);
-	bool run_playfx           (Game &, State &, const Action &);
+	bool run_play_sound       (Game &, State &, const Action &);
 	bool run_construct        (Game &, State &, const Action &);
 
 	OPtr<PlayerImmovable> location_; ///< meta location of the worker

=== modified file 'src/logic/map_objects/tribes/worker_program.cc'
--- src/logic/map_objects/tribes/worker_program.cc	2016-02-02 12:38:05 +0000
+++ src/logic/map_objects/tribes/worker_program.cc	2016-02-16 15:29:05 +0000
@@ -46,9 +46,9 @@
 	{"create_bob",        &WorkerProgram::parse_create_bob},
 	{"removeobject",      &WorkerProgram::parse_removeobject},
 	{"geologist",         &WorkerProgram::parse_geologist},
-	{"geologist-find",    &WorkerProgram::parse_geologist_find},
+	{"geologist_find",    &WorkerProgram::parse_geologist_find},
 	{"scout",             &WorkerProgram::parse_scout},
-	{"playFX",            &WorkerProgram::parse_play_fx},
+	{"play_sound",        &WorkerProgram::parse_play_sound},
 	{"construct",         &WorkerProgram::parse_construct},
 
 	{nullptr, nullptr}
@@ -541,7 +541,7 @@
 void WorkerProgram::parse_geologist_find(Worker::Action* act, const std::vector<std::string>& cmd)
 {
 	if (cmd.size() != 1)
-		throw wexception("Usage: geologist-find");
+		throw wexception("Usage: geologist_find");
 
 	act->function = &Worker::run_geologist_find;
 }
@@ -564,16 +564,16 @@
 	act->function = &Worker::run_scout;
 }
 
-void WorkerProgram::parse_play_fx(Worker::Action* act, const std::vector<std::string>& cmd)
+void WorkerProgram::parse_play_sound(Worker::Action* act, const std::vector<std::string>& cmd)
 {
 	if (cmd.size() < 3 || cmd.size() > 4)
-		throw wexception("Usage: playFX <fx_dir> <fx_name> [priority]");
+		throw wexception("Usage: play_sound <sound_dir> <sound_name> [priority]");
 
 	act->sparam1 = cmd[1] + "/" + cmd[2];
 
 	g_sound_handler.load_fx_if_needed(cmd[1], cmd[2], act->sparam1);
 
-	act->function = &Worker::run_playfx;
+	act->function = &Worker::run_play_sound;
 	act->iparam1 =
 		cmd.size() == 3 ?
 		64 : //  50% chance to play, only one instance at a time

=== modified file 'src/logic/map_objects/tribes/worker_program.h'
--- src/logic/map_objects/tribes/worker_program.h	2016-02-02 12:38:05 +0000
+++ src/logic/map_objects/tribes/worker_program.h	2016-02-16 15:29:05 +0000
@@ -82,7 +82,7 @@
 	void parse_geologist        (Worker::Action* act, const std::vector<std::string>& cmd);
 	void parse_geologist_find   (Worker::Action* act, const std::vector<std::string>& cmd);
 	void parse_scout            (Worker::Action* act, const std::vector<std::string>& cmd);
-	void parse_play_fx          (Worker::Action* act, const std::vector<std::string>& cmd);
+	void parse_play_sound       (Worker::Action* act, const std::vector<std::string>& cmd);
 	void parse_construct        (Worker::Action* act, const std::vector<std::string>& cmd);
 
 	const std::string name_;

=== modified file 'src/map_io/map_buildingdata_packet.cc'
--- src/map_io/map_buildingdata_packet.cc	2016-02-13 12:15:29 +0000
+++ src/map_io/map_buildingdata_packet.cc	2016-02-16 15:29:05 +0000
@@ -61,7 +61,7 @@
 constexpr uint16_t kCurrentPacketPFBuilding = 1;
 constexpr uint16_t kCurrentPacketVersionWarehouse = 6;
 constexpr uint16_t kCurrentPacketVersionMilitarysite = 5;
-constexpr uint16_t kCurrentPacketVersionProductionsite = 5;
+constexpr uint16_t kCurrentPacketVersionProductionsite = 6;
 constexpr uint16_t kCurrentPacketVersionTrainingsite = 4;
 
 void MapBuildingdataPacket::read

=== modified file 'src/sound/sound_handler.h'
--- src/sound/sound_handler.h	2016-02-06 11:11:24 +0000
+++ src/sound/sound_handler.h	2016-02-16 15:29:05 +0000
@@ -86,7 +86,7 @@
  * \par Sound effects
  *
  * Buildings and workers can use sound effects in their programs. To do so, use
- * e.g. "playFX blacksmith_hammer" in the appropriate conf file. The conf file
+ * e.g. "play_sound blacksmith_hammer" in the appropriate conf file. The conf file
  * parser will then load one or more audio files for 'hammering blacksmith'
  * from the building's/worker's configuration directory and store them in an
  * FXset for later access, similar to the way music is stored in songsets.


Follow ups
--- src/graphic/animation.cc	2016-02-13 12:15:29 +0000
+++ src/graphic/animation.cc	2016-02-16 15:29:05 +0000
@@ -74,7 +74,7 @@
 	const std::string& representative_image_filename() const override;
 	virtual void blit(uint32_t time, const Point&, const Rect& srcrc, const RGBColor* clr, Surface*)
 		const override;
-	void trigger_soundfx(uint32_t framenumber, uint32_t stereo_position) const override;
+	void trigger_sound(uint32_t framenumber, uint32_t stereo_position) const override;
 
 
 private:
@@ -96,7 +96,7 @@
 	vector<const Image*> pcmasks_;
 
 	// name of sound effect that will be played at frame 0.
 	// TODO(sirver): this should be done using playFX in a program instead of
 	// binding it to the animation.
 	string sound_effect_;
 	bool play_once_;
@@ -251,7 +251,7 @@
 	return 0;
 }
 
-void NonPackedAnimation::trigger_soundfx(uint32_t time, uint32_t stereo_position) const {
+void NonPackedAnimation::trigger_sound(uint32_t time, uint32_t stereo_position) const {
 	if (sound_effect_.empty()) {
 		return;
 	}
@@ -96,7 +96,7 @@
 
 	// name of sound effect that will be played at frame 0.
-	// TODO(sirver): this should be done using playFX in a program instead of
+	// TODO(sirver): this should be done using play_sound in a program instead of
 	// binding it to the animation.
 	string sound_effect_;

=== modified file 'src/graphic/animation.h'
--- src/graphic/rendertarget.cc	2016-01-27 08:06:40 +0000
+++ src/graphic/rendertarget.cc	2016-02-16 15:29:05 +0000
@@ -288,7 +288,7 @@
 /**
  * Draws a frame of an animation at the given location
  * Plays sound effect that is registered with this frame (the SoundHandler
  * decides if the fx really does get played)
  *
  * \param dstx, dsty the on-screen location of the animation hot spot
  * \param animation the animation ID
@@ -338,7 +338,7 @@
 	// effect (see SoundHandler::stereo_position).
 	// TODO(sirver): Playing a sound effect in here is rather silly. What if
 	// this animation is used in the menus?
-	animation.trigger_soundfx(time, 128);
+	animation.trigger_sound(time, 128);
 }
 
 /**
@@ -288,7 +288,7 @@
  * Draws a frame of an animation at the given location
  * Plays sound effect that is registered with this frame (the SoundHandler
- * decides if the fx really does get played)
+ * decides if the sound really does get played)
  *
  * \param dstx, dsty the on-screen location of the animation hot spot

=== modified file 'src/logic/map_objects/immovable.cc'